@@ -133,14 +133,16 @@ def format_string(text):
 
 
 def format_number(strNum):
-    if '千' in strNum:
-        strNum = int(float(strNum.split("千")[0]) * 1000)
-    elif '万' in strNum:
-        strNum = int(float(strNum.split("万")[0]) * 10000)
-    elif '百万' in strNum:
-        strNum = int(float(strNum.split("百万")[0]) * 1000000)
+    if '亿' in strNum:
+        ret = int(float(strNum.split("亿")[0]) * 100000000)
     elif '千万' in strNum:
-        strNum = int(float(strNum.split("千万")[0]) * 10000000)
-    elif '亿' in strNum:
-        strNum = int(float(strNum.split("亿")[0]) * 100000000)
-    return strNum
+        ret = int(float(strNum.split("千万")[0]) * 10000000)
+    elif '百万' in strNum:
+        ret = int(float(strNum.split("百万")[0]) * 1000000)
+    elif '千' in strNum:
+        ret = int(float(strNum.split("千")[0]) * 1000)
+    elif '万' in strNum:
+        ret = int(float(strNum.split("万")[0]) * 10000)
+    else:
+        ret = int(strNum)
+    return ret
